## Load appropriate libraries

library(ggplot2)
library(phyloseq)
library(ape)
library(xlsx)
library(plyr)
library(reshape)
library(gridExtra)
library(vegan)
library(rich)
library(grid)
library(RColorBrewer)
library(caret)
library(car)
library(rgl)
library(tsne)
source("SummarySE.R")
library(stringr)


##########################################################################

## Reading in data
raw_cnts = readRDS("Virome_raw_counts.RDS")
meta_data = readRDS("Virome_meta_data.RDS")


#Ensure order is correct
meta_data = meta_data[colnames(raw_cnts),]

#Reset levels for later plotting
meta_data$Alpha_type = factor(meta_data$Alpha_type,levels = c("Donor","CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo"))

#Convert raw counts to proportional data per sample
cnts_prop = prop.table(as.matrix(raw_cnts),2)
cnts_prop = cnts_prop * 100

##########################################################################

## PCoA and distance calculation
OTU = otu_table(cnts_prop,taxa_are_rows =TRUE)
map_data = sample_data(meta_data)
physeq = phyloseq(OTU,map_data)

OTU_raw = otu_table(raw_cnts,taxa_are_rows =TRUE)
physeq_raw = phyloseq(OTU_raw,map_data)
alpha_div = estimate_richness(physeq_raw)#

# Bray Curtis distance in PhyloSeq
braycurtis_dist = phyloseq::distance(physeq,method="bray")
braycurtis_pc = pcoa(braycurtis_dist)

##########################################################################
# Prepare data frame for plotting
PC_data.df = data.frame(meta_data,
                        alpha_div,
                        "BC1" = braycurtis_pc$vectors[,1],
                        "BC2" = braycurtis_pc$vectors[,2])



# Beta Diversity plot (Figure 1A)

ggplot(PC_data.df,aes(x = BC1, y = BC2,color=Donor))+geom_point()+
  xlab(paste("PC1:",round(braycurtis_pc$values$Relative_eig[1]*100,2)," variation"))+
  ylab(paste("PC2:",round(braycurtis_pc$values$Relative_eig[2]*100,2)," variation"))+
  ggtitle("Bray Curtis virome") + theme_classic()+
  stat_ellipse(aes(x = BC1,y =BC2, fill=Donor),geom="polygon",level=0.7,alpha=0.3)

# Alpha Diversity plot (Supplementary Figure 2)


ggplot(PC_data.df,aes(x=Alpha_type,y=Shannon,fill=Alpha_type))+geom_boxplot()+
  theme_classic()+ggtitle("Shannon diversity")
ggplot(PC_data.df,aes(x=Alpha_type,y=Chao1,fill=Alpha_type))+geom_boxplot()+
  theme_classic()+ggtitle("Chao1 diversity")




################################################################################################
## Code below generates spearman correlation between samples.
## This is for Figure 1B


#### Similarity of recipient to their donor ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
  person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
  donor2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"DonorSamp"])
  corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
  cors = c(cors,corsp)
}
names(cors) = 
assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
rownames(cors_id_CDI) = c("P1","P2","P3","P4","P5","P6","P7","P8","P10","P11","P12","P13")
CDI_cors = cors_id_CDI

cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_their_donor = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
ggtitle("Recipient similarity to donor")
sim2donor = sumSEtp
sim2donor = data.frame(sim2donor,"sim2" = rep("sim2orig",nrow(sim2donor)))

#### Similarity of recipient to other donors ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
    pDonor = unique(as.character(meta_data[meta_data$Person==Patient,"Donor_noNA"]))
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[!meta_data$Person==pDonor & meta_data$Sim_time==stime & meta_data$Type=="Donor","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_other_donors = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
sim2other = sumSEtp
sim2other = data.frame(sim2other,"sim2" = rep("sim2other",nrow(sim2other)))


#### Intra donor Similarity ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("D1","D2","D3")){
    pDonor = Patient
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[meta_data$Person==pDonor & meta_data$Sim_time=="CDI" & meta_data$Type=="Donor","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
donor_sim_to_themselves = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
donorsim2 = sumSEtp
donorsim2 = data.frame(donorsim2,"sim2" = rep("donorsim2",nrow(donorsim2)))

toplot_sim = rbind(sim2donor,sim2other,donorsim2)

#### Intra patient Similarity ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
    pDonor = Patient
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[meta_data$Person==pDonor & meta_data$Sim_time=="CDI","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_themselves = toplot_cors
sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
patsim2 = sumSEtp
patsim2 = data.frame(patsim2,"sim2" = rep("patsim2",nrow(patsim2)))

toplot_sim = rbind(sim2donor,sim2other,donorsim2,patsim2)


ggplot(toplot_sim,aes(x = ID,y = cors,color=sim2))+
  geom_errorbar(aes(ymin =cors-se,ymax=cors+se),width=0.1)+
  geom_line(aes(group=sim2))+geom_point()+theme_classic()+ylim(c(0,1))+
  ggtitle("Similarity plot")+scale_color_manual(values=c("#008744","#45c8fc","#d62d20","#be29ec"))



################################################################################################
## Abundance of families (Figure 2 A)


kaiju_counts = readRDS("Kaiju_counts.RDS")

ggplot(kaiju_tp2,aes(x = variable,y = log(value),fill=Alpha_type))+
  geom_boxplot(aes(fill=Alpha_type))+theme_bw()+
  ylab("Log Relative abundance (%)")+theme(axis.text.x=element_text(angle=45,hjust=1))+#
  scale_fill_manual(values=c("#d4af37","#b376e7","#295443","#a6c500","#6cc1b2","#11f64e","#85e1d5","#8cc17b","#e77d7d"))



################################################################################################
## Abundance of specific phage (Figure 2 B & C)
relabun = data.frame(meta_data,t(cnts_prop[,rownames(meta_data)]))


relabunD3 = relabun[relabun$Person %in% c("P6","P10","P8","P12","P14"),]

crass = ggplot(relabunD3,aes(x=Alpha_type,y=NG_11762_35_P14_F5.NODE_1_length_99255_cov_657.479,color=Person))+geom_line(aes(group=Person),size=2)+
  theme_classic()+ggtitle("CrAssphage in Donor 3 recipients")+scale_color_brewer(palette = "Dark2")+theme(axis.text.x = element_text(angle = 45, hjust = 1))+ylim(0,100)

  
relabunD2 = relabun[relabun$Person %in% c("P1","P13","P2","P3","P4","P5"),]

micro1 = ggplot(relabunD2,aes(x=Alpha_type,y=NG_11762_106_P1_F3.NODE_10_length_7591_cov_19833.4,color=Person))+geom_line(aes(group=Person),size=2)+
  theme_classic()+ggtitle("Abundant Microviridae in Donor 2 recipients")+ylim(0,100)+scale_color_brewer(palette = "Set1")+theme(axis.text.x = element_text(angle = 45, hjust = 1))
caudo1 = ggplot(relabunD2,aes(x=Alpha_type,y=NG_11762_90_P5_F5.NODE_3_length_86873_cov_234.566,color=Person))+geom_line(aes(group=Person),size=2)+
  theme_classic()+ggtitle("Caudovirales contig in Donor 2 recipients")+scale_color_brewer(palette = "Set1")+theme(axis.text.x = element_text(angle = 45, hjust = 1))

unclass_vir = ggplot(relabunD3,aes(x=Alpha_type,y=NG_11762_37_P9_F1.NODE_6_length_44025_cov_22.2373,color=Person))+geom_line(aes(group=Person),size=2)+
  theme_classic()+ggtitle("Unclassified contig in Donor 3 recipients")+scale_color_brewer(palette = "Dark2")+theme(axis.text.x = element_text(angle = 45, hjust = 1))

grid.arrange(caudo1,micro1,crass,unclass_vir,nrow=2)




################################################################################################

# This generates the barplot of sample abundance by viral origin (Figure 3)

pats = droplevels(meta_data[meta_data$Donor2=="CDI","Person"]) #Just patients that have Pre FMT sample
abun_counts = data.frame(names = c("common","recip_specific","donor_specific","new_detected","pfmt_new_detected"))
ledf = data.frame("names" = c("common","recipient_specific","donor_specific","new","total"))
origin_raw = data.frame("origin" = c("common","donor_specific","new_detected","pfmt_detected","recip_specific"))
rownames(origin_raw) = origin_raw$origin
for (sampno in c(1,2,3,4,5,6,7)){
  
  print(sampno)
  samp = paste("F",as.character(sampno),sep = "")
  for (pat in pats){
    
    prefmtsamp = rownames(meta_data[meta_data$Donor2=="CDI" & meta_data$Person == pat,])
    othersamps = rownames(meta_data[meta_data$Donor2=="Post_FMT" & meta_data$Person == pat,])
    othersample = othersamps[which(grepl(samp,as.list(othersamps))==TRUE)]
    othersamps = othersamps[-(which(grepl(samp,as.list(othersamps))==TRUE))]
    timepoint = c()
    for (x in othersamps){
      timepoint = c(timepoint,str_sub(x,start=-1))}
    othersamps = othersamps[timepoint<sampno]
    
    if (length(othersample)!=0 & length(othersamps) != 0){
      
      donorsamp = as.character(meta_data[meta_data$Person == pat,"DonorSamp"][1])
      
      comp = raw_cnts2[,c(prefmtsamp,donorsamp,othersample,othersamps)]
      common = apply(comp[comp[,1]>0 & comp[,2]>0 & comp[,3] > 0,],2,sum)
      recip_specific = apply(comp[comp[,1]>0 & comp[,2]==0 & comp[,3]>0,],2,sum)
      donor_specific = apply(comp[comp[,1]==0 & comp[,2]>0 & comp[,3]>0,],2,sum)
      pfmt_new_detected = NA
      if (ncol(comp) > 4){
        new_detected = apply(comp[comp[,1]==0 & comp[,2]==0 & comp[,3]>0 & apply(comp[,4:ncol(comp)],1,function(x){all(x == 0)}),],2,sum)
        pfmt_new_detected = apply(comp[comp[,1]==0 & comp[,2]==0 & comp[,3]>0 & apply(comp[,4:ncol(comp)],1,function(x){any(x > 0)}),],2,sum)
        abun_ori = rbind(common,recip_specific,donor_specific,new_detected,pfmt_new_detected)
        
        
      } else if (ncol(comp) == 4){
        new_detected = apply(comp[comp[,1]==0 & comp[,2]==0 & comp[,3]>0 & comp[,4] == 0,],2,sum)
        pfmt_new_detected = apply(comp[comp[,1]==0 & comp[,2]==0 & comp[,3]>0 & comp[,4] > 0,],2,sum)
        abun_ori = rbind(common,recip_specific,donor_specific,new_detected,pfmt_new_detected)
        
        
      } else if (ncol(comp) < 4) {
        new_detected = apply(comp[comp[,1]==0 & comp[,2]==0 & comp[,3]>0,],2,sum)
        pfmt_new_detected = common
        pfmt_new_detected[pfmt_new_detected>0] = 0
        abun_ori = rbind(common,recip_specific,donor_specific,new_detected,pfmt_new_detected)
        
      }
      abun_ori = rbind(common,recip_specific,donor_specific,new_detected,pfmt_new_detected)
      
      abun_counts = cbind(abun_counts,abun_ori)
      
      
    }
  }
}

abun_counts_prop = prop.table(as.matrix(abun_counts[,-1]),2)
touse = rownames(meta_data)[rownames(meta_data) %in% colnames(abun_counts_prop)]
xyt = data.frame(meta_data[touse,],t(abun_counts_prop[,touse]))
xyt = xyt[!xyt$Type=="Donor",]

xyt$Alpha_type = factor(xyt$Alpha_type,levels = c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo"))
xyt$Person = factor(xyt$Person,levels = c("P7","P1","P2","P3","P4","P5","P13","P6","P8","P9","P10","P11","P11","P12","P14"))
xyy = melt(xyt[,c("Person","Alpha_type","donor_specific","recip_specific","new_detected","pfmt_new_detected","common")])

ggplot(xyy,aes(y = value,x=Alpha_type,fill=variable))+geom_bar(position = "fill",stat = "identity")+
  theme_bw()+scale_fill_manual(values = c("#08ab7e","#b62da9","#2a96b6","#dba500","#b42f2f"))+facet_wrap(~Person,scales="free")+
  theme(axis.text.x = element_text(angle = 45, hjust = 1))




################################################################################################
## 16S analysis PCoA plot

raw_cnts = readRDS("16S_raw_counts")

rownames(meta_data)[!rownames(meta_data) %in% colnames(raw_cnts)]

meta_data = meta_data[colnames(raw_cnts),]

cnts_prop = prop.table(as.matrix(raw_cnts),2)
cnts_prop = cnts_prop * 100

OTU = otu_table(cnts_prop,taxa_are_rows =TRUE)
map_data = sample_data(meta_data)
physeq = phyloseq(OTU,map_data)

braycurtis_dist = phyloseq::distance(physeq,method="bray")
braycurtis_pc = pcoa(braycurtis_dist)

jaccard_dist = phyloseq::distance(physeq, method = "jaccard")#, binary = TRUE)
jaccard_pc = pcoa(jaccard_dist)

PC_data.df = data.frame(meta_data,
                        "BC1" = braycurtis_pc$vectors[,1],
                        "BC2" = braycurtis_pc$vectors[,2])

ggplot(PC_data.df,aes(x = BC1, y = BC2,color=Donor))+geom_point()+
  xlab(paste("PC1:",round(braycurtis_pc$values$Relative_eig[1]*100,2)," variation"))+
  ylab(paste("PC2:",round(braycurtis_pc$values$Relative_eig[2]*100,2)," variation"))+
  ggtitle("Bray Curtis 16S Microbiota") + theme_classic()+
  stat_ellipse(aes(x = BC1,y =BC2, fill=Donor),geom="polygon",level=0.7,alpha=0.3) 







#### Similarity of recipient to their donor ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"DonorSamp"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
rownames(cors_id_CDI) = c("P1","P2","P3","P4","P5","P6","P7","P8","P10","P11","P12","P13")
CDI_cors = cors_id_CDI

cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_their_donor = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
ggtitle("Recipient similarity to donor")
sim2donor = sumSEtp
sim2donor = data.frame(sim2donor,"sim2" = rep("sim2orig",nrow(sim2donor)))

#### Similarity of recipient to other donors ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
    pDonor = unique(as.character(meta_data[meta_data$Person==Patient,"Donor_noNA"]))
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[!meta_data$Person==pDonor & meta_data$Sim_time==stime & meta_data$Type=="Donor","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_other_donors = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
sim2other = sumSEtp
sim2other = data.frame(sim2other,"sim2" = rep("sim2other",nrow(sim2other)))


#### Intra donor Similarity ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("D1","D2","D3")){
    pDonor = Patient
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[meta_data$Person==pDonor & meta_data$Sim_time=="CDI" & meta_data$Type=="Donor","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
donor_sim_to_themselves = toplot_cors

sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
donorsim2 = sumSEtp
donorsim2 = data.frame(donorsim2,"sim2" = rep("donorsim2",nrow(donorsim2)))

toplot_sim = rbind(sim2donor,sim2other,donorsim2)

#### Intra patient Similarity ####

for (stime in c("CDI","3d","2wks","1_mo","2_mo","4_mo","8_mo","12_mo")){
  cors = c()
  for (Patient in c("P1","P2","P3","P4","P5","P6","P7","P8","P9","P10","P11","P12","P13","P14")){
    pDonor = Patient
    person2cor = as.character(meta_data[meta_data$Person==Patient & meta_data$Sim_time==stime,"Sample"])
    donor2cor = as.character(meta_data[meta_data$Person==pDonor & meta_data$Sim_time=="CDI","Sample"])
    corsp = cor(cnts_prop[,person2cor],cnts_prop[,donor2cor],method = "spearman")
    cors = c(cors,corsp)
  }
  names(cors) = 
    assign(paste("cors",stime,sep="_"),cors)
}

cors_id_CDI = data.frame(cors = cors_CDI,ID = rep("CDI",length(cors_CDI)))
cors_id_3d = data.frame(cors = cors_3d,ID = rep("3d",length(cors_3d)))
cors_id_2wks = data.frame(cors = cors_2wks,ID = rep("2wks",length(cors_2wks)))
cors_id_1mo = data.frame(cors = cors_1_mo,ID = rep("1_mo",length(cors_1_mo)))
cors_id_2mo = data.frame(cors = cors_2_mo,ID = rep("2_mo",length(cors_2_mo)))
cors_id_4mo = data.frame(cors = cors_4_mo,ID = rep("4_mo",length(cors_4_mo)))
cors_id_8mo = data.frame(cors = cors_8_mo,ID = rep("8_mo",length(cors_8_mo)))
cors_id_12mo = data.frame(cors = cors_12_mo,ID = rep("12_mo",length(cors_12_mo)))
toplot_cors = do.call("rbind",list(cors_id_CDI,cors_id_3d,cors_id_2wks,cors_id_1mo,
                                   cors_id_2mo,cors_id_4mo,cors_id_8mo,cors_id_12mo))
recip_sim_to_themselves = toplot_cors
sumSEtp = summarySE(toplot_cors,measurevar = "cors",groupvars = c("ID"))
patsim2 = sumSEtp
patsim2 = data.frame(patsim2,"sim2" = rep("patsim2",nrow(patsim2)))

toplot_sim = rbind(sim2donor,sim2other,donorsim2,patsim2)


ggplot(toplot_sim,aes(x = ID,y = cors,color=sim2))+
  geom_errorbar(aes(ymin =cors-se,ymax=cors+se),width=0.1)+
  geom_line(aes(group=sim2))+geom_point()+theme_classic()+ylim(c(0,1))+
  ggtitle("Similarity plot")+scale_color_manual(values=c("#008744","#45c8fc","#d62d20","#be29ec"))


